@@ -110,8 +110,8 @@ main(argc, argv)
     register char *tcp;
     register int f;
     register char **tempv;
-/*    struct sigvec osv;*/
-    struct sigaction oact;    /* I guess this is like sigvec? */
+    struct sigvec osv;
+
 
     settimes();			/* Immed. estab. timing base */
 
@@ -128,7 +128,6 @@ main(argc, argv)
     environ = short2blk(STR_environ);	/* So that we can free it */
     STR_WORD_CHARS = SAVE(WORD_CHARS);
 
-
     HIST = '!';
     HISTSUB = '^';
     word_chars = STR_WORD_CHARS;
@@ -230,17 +229,11 @@ main(argc, argv)
      * only if we are the login shell.
      */
     /* parents interruptibility */
-/*    (void) sigvec(SIGINT, NULL, &osv); 
+    (void) sigvec(SIGINT, NULL, &osv);
     parintr = (void (*) ()) osv.sv_handler;
     (void) sigvec(SIGTERM, NULL, &osv);
     parterm = (void (*) ()) osv.sv_handler;
-*/
-	
-    sigaction(SIGINT, NULL, &oact);	/* is this is correct? */
-    parintr = oact.sa_handler;
-    sigaction(SIGTERM, NULL, &oact);
-    parterm = oact.sa_handler;
-    
+
     if (loginsh) {
 	(void) signal(SIGHUP, phup);	/* exit processing on HUP */
 	(void) signal(SIGXCPU, phup);	/* ...and on XCPU */
