@@ -35,8 +35,6 @@
 static char sccsid[] = "@(#)func.c	5.20 (Berkeley) 6/27/91";
 #endif /* not lint */
 
-#define notdef	/* what is up with this anyway? See resource.h */
-
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <signal.h>
@@ -54,7 +52,6 @@ static char sccsid[] = "@(#)func.c	5.20 (Berkeley) 6/27/91";
 #include "extern.h"
 #include "pathnames.h"
 
-
 extern char **environ;
 
 static int zlast = -1;
@@ -1047,7 +1044,11 @@ static struct limits {
     RLIMIT_RSS,		"memoryuse", 	1024,	"kbytes",
     RLIMIT_MEMLOCK,	"memorylocked",	1024,	"kbytes",
     RLIMIT_NPROC,	"maxproc",	1,	"",
+#ifdef RLIMIT_NOFILE
+    RLIMIT_NOFILE,	"openfiles",	1,	"",
+#else
     RLIMIT_OFILE,	"openfiles",	1,	"",
+#endif
     -1, 		NULL, 		0,	NULL
 };
 
@@ -1111,7 +1112,7 @@ getval(lp, v)
     Char  **v;
 {
     register float f;
-/*    double  atof();*/
+    double  atof();
     Char   *cp = *v++;
 
     f = atof(short2str(cp));
