@@ -354,8 +354,12 @@ static Char **
 libglob(vl)
     Char  **vl;
 {
-    int     gflgs = /*GLOB_QUOTE |*/ GLOB_NOCHECK;
-    glob_t  globv;  /* ^-- why is there not GLOB_QUOTE in the gnu glob? */   
+#ifdef GLOB_QUOTE
+    int     gflgs = GLOB_QUOTE | GLOB_NOCHECK;
+#else
+    int     gflgs = GLOB_NOCHECK;
+#endif
+    glob_t  globv;
     char   *ptr;
 
     globv.gl_offs = 0;
@@ -375,7 +379,10 @@ libglob(vl)
 	default:
 	    break;
 	}
-	if (!nonomatch && (globv.gl_pathc == 0) && /* changed .gl_matchc */
+	if (!nonomatch &&
+#ifndef __linux__
+	    (globv.gl_matchc == 0) &&
+#endif
 	    (globv.gl_flags & GLOB_MAGCHAR)) {
 	    globfree(&globv);
 	    return (NULL);
